@include portal-type-font-awesome-icon(ftw-events-eventfolder, calendar);
@include portal-type-font-awesome-icon(ftw-events-eventpage, calendar-o);
@include portal-type-font-awesome-icon(ftw-events-eventlistingblock, calendar-o);


.event-details {
  .when {
    margin-bottom: $margin-vertical;
    ul {
      @include list;
    }
  }
}

.event-row {
  @include list();
  margin-bottom: $margin-vertical;

  > li:last-child .event-item {
    margin-bottom: 0;
  }

  .event-item {
    @include no-link();
    @include clearfix();
    padding: 0;
    margin-bottom: $margin-vertical;

    &:hover {
      background-color: $color-gray-light;
    }

    .body {
      .event-more {
        display: inline;
        &:before {
          min-width: 0;
        }
      }
    }

    .byline {
      display: block;
      font-size: $font-size-small;
      color: $color-text-light;
    }

    .title {
      font-size: 1rem;
      font-weight: bold;
      display: block;
    }
  }
}

#document-action-ics_export a{
    @extend .fa-icon;
    @extend .fa-calendar;
}
#document-action-ics_export a {
    font-size: 0px;
}

#document-action-ics_export > a:before {
    padding-left: 0.5em;
    font-size: 1.2rem;
}